==> haskell-yesod-default-1.2.0-747-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-default
version:              1.2.0
visibility:           public
id:                   yesod-default-1.2.0-GAEOsITbsvpBdKeUfJJNg
key:                  yesod-default-1.2.0-GAEOsITbsvpBdKeUfJJNg
license:              MIT
maintainer:           Patrick Brisbin <pbrisbin@gmail.com>
author:               Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:
    Default config and main functions for your yesod application (deprecated)

description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application

category:             Web, Yesod
abi:                  e5bc56b8c2a35c4e76347140bbd0541d
exposed:              True
exposed-modules:      Yesod.Default.Ignore
import-dirs:          /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/yesod-default-1.2.0
hs-libraries:         HSyesod-default-1.2.0-GAEOsITbsvpBdKeUfJJNg
depends:
    base-4.14.0.0 yesod-core-1.6.18-FaDR7T2V2s4LWSSm8r8j8H

haddock-interfaces:
    /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock

haddock-html:         /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-748-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-default
version:              1.2.0
visibility:           public
id:                   yesod-default-1.2.0-J7TcjfgQuej7wUXfuPU4QF
key:                  yesod-default-1.2.0-J7TcjfgQuej7wUXfuPU4QF
license:              MIT
maintainer:           Patrick Brisbin <pbrisbin@gmail.com>
author:               Patrick Brisbin
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:
    Default config and main functions for your yesod application (deprecated)

description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application

category:             Web, Yesod
abi:                  5d1ce607f16da6efce53ba98898854e0
exposed:              True
exposed-modules:      Yesod.Default.Ignore
import-dirs:          /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
library-dirs:         /usr/lib/ghc-8.10.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/yesod-default-1.2.0
hs-libraries:         HSyesod-default-1.2.0-J7TcjfgQuej7wUXfuPU4QF
depends:              base-4.14.0.0 yesod-core-1.6.18-d2WNdFFTELEPDYfPrgvoN
haddock-interfaces:
    /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock

haddock-html:         /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
